@@ -790,17 +790,15 @@ be_interface:: gen_var_out_seq_decls (void)
       << "class " << lname << ";" << be_nl
       << "typedef " << lname << " *" << lname << "_ptr;";
 
-  *os << be_nl_2
-      << "typedef" << be_idt_nl
-      << "TAO_Objref_Var_T<" << be_idt << be_idt_nl
-      << lname << be_uidt_nl
-      << ">" << be_uidt_nl
-      << lname << "_var;" << be_uidt_nl << be_nl
-      << "typedef" << be_idt_nl
-      << "TAO_Objref_Out_T<" << be_idt << be_idt_nl
-      << lname << be_uidt_nl
-      << ">" << be_uidt_nl
-      << lname << "_out;" << be_uidt;
+  *os << be_nl
+      << "typedef TAO_Objref_Var_T<"
+      << lname
+      << "> "
+      << lname << "_var;" << be_nl
+      << "typedef TAO_Objref_Out_T<"
+      << lname
+      << "> "
+      << lname << "_out;" << be_nl;
 
   os->gen_endif ();
 
@@ -1857,7 +1855,7 @@ int
 be_interface::gen_gperf_things (const char *flat_name)
 {
   // GPERF can give Binary search, Linear search and Perfect Hash
-  // methods. Generate the class defintion according to that.
+  // methods. Generate the class definition according to that.
 
   TAO_OutStream *os = tao_cg->server_skeletons ();
 
