@@ -675,6 +675,11 @@ be_util::usage (void)
       ACE_TEXT (" -Guc\t\t\tgenerate uninlined constant if declared ")
       ACE_TEXT ("in a module (inlined by default)\n")
     ));
+  ACE_DEBUG ((
+      LM_DEBUG,
+      ACE_TEXT (" -Gsd\t\t\tgenerate static description operations which can ")
+      ACE_TEXT ("be useful for template programming (not generated by default)\n")
+    ));
   ACE_DEBUG ((
       LM_DEBUG,
       ACE_TEXT (" -Gse\t\t\tgenerate explicit export of sequence's ")
