@@ -2,11 +2,8 @@
 /**
  *  @file    Server_Info.h
  *
- *  $Id: Server_Info.h 97567 2014-02-06 23:33:48Z mesnier_p $
- *
  *  This class implements the Server_Info for the Implementation Repository.
  *
- *
  *  @author Darrell Brunsch <brunsch@cs.wustl.edu>
  *  @author Priyanka Gontla <gontla_p@ociweb.com>
  */
@@ -43,8 +40,7 @@ struct Server_Info
                int start_limit,
                const ACE_CString& partial_ior = ACE_CString(""),
                const ACE_CString& server_ior = ACE_CString(""),
-               ImplementationRepository::ServerObject_ptr svrobj = ImplementationRepository::ServerObject::_nil()
-    );
+               ImplementationRepository::ServerObject_ptr svrobj = ImplementationRepository::ServerObject::_nil());
 
   Server_Info (const ACE_CString& serverId,
                const ACE_CString& pname,
@@ -61,9 +57,12 @@ struct Server_Info
 
   void reset_runtime (void);
 
-  bool is_server (const char *name);
-  bool has_peer (const char *name);
+  bool is_server (const char *name) const;
+  bool has_peer (const char *name) const;
   bool is_mode (ImplementationRepository::ActivationMode m) const;
+  bool is_running (void) const;
+  bool start_allowed (void);
+  void started (bool success);
 
   // transform the supplied limit to always be at least 1
   void start_limit (int lim);
@@ -112,6 +111,8 @@ struct Server_Info
   ImplementationRepository::ActivationMode activation_mode_;
   /// Limit of retries to start the server
   int start_limit_;
+  /// Current number of start attempts
+  int start_count_;
   /// Current endpoint used by the server.
   ACE_CString partial_ior;
   /// IOR of the server object in the server.
@@ -125,11 +126,10 @@ struct Server_Info
   /// Alternate server info for sharing startup info between linked POAs
   Server_Info_Ptr alt_info_;
 
-  int start_count;
-  int waiting_clients;
-  bool starting;
+  /// Last known process ID reported by the activator
   int pid;
-
+  /// the locator should expect a notification on server death from activator
+  bool death_notify;
 };
 
 #endif /* SERVER_INFO_H */
