@@ -3,8 +3,6 @@
 /**
  *  @file   CosPropertyService_i.cpp
  *
- *  $Id: CosPropertyService_i.cpp 97014 2013-04-12 22:47:02Z mitza $
- *
  *  @author Alexander Babu Arulanthu <alex@cs.wustl.edu>
  */
 //=============================================================================
@@ -769,7 +767,7 @@ TAO_PropertySet::get_properties (const CosPropertyService::PropertyNames &proper
 
   // Get values for all the names.
 
-  CORBA::Any_ptr any_ptr = 0;
+  CORBA::Any_var any_ptr = 0;
   CORBA::Boolean ret_val = 1;
 
   for (CORBA::ULong i = 0; i < n; i++)
