@@ -1,6 +1,4 @@
 // -*- C++ -*-
-// $Id: IIOP_Profile.cpp 96992 2013-04-11 18:07:48Z huangh $
-
 #include "tao/IIOP_Profile.h"
 
 #if defined (TAO_HAS_IIOP) && (TAO_HAS_IIOP != 0)
@@ -12,6 +10,7 @@
 #include "tao/SystemException.h"
 #include "ace/OS_NS_string.h"
 #include "ace/OS_NS_stdio.h"
+#include "ace/Truncate.h"
 #include "ace/os_include/os_netdb.h"
 
 static const char the_prefix[] = "iiop";
@@ -116,10 +115,12 @@ TAO_IIOP_Profile::decode_profile (TAO_InputCDR& cdr)
       this->endpoint_.object_addr_.set_type (-1);
 
       const char* csv = this->orb_core()->orb_params()->preferred_interfaces();
-      bool const enforce =
-        this->orb_core()->orb_params()->enforce_pref_interfaces();
-      this->count_ += this->endpoint_.preferred_interfaces(csv, enforce, *this);
-
+      if (csv != 0 && *csv != '\0')
+        {
+          bool const enforce =
+            this->orb_core()->orb_params()->enforce_pref_interfaces();
+          this->count_ += this->endpoint_.preferred_interfaces(csv, enforce, *this);
+        }
       return 1;
     }
 
@@ -210,7 +211,7 @@ TAO_IIOP_Profile::parse_string_i (const char *ior)
   else if (cp_pos != 0)
     {
       // A port number or port name was specified.
-      CORBA::ULong length_port = okd - cp_pos - 1;
+      CORBA::ULong length_port = ACE_Utils::truncate_cast<CORBA::ULong> (okd - cp_pos - 1);
       CORBA::String_var tmp = CORBA::string_alloc (length_port);
 
       if (tmp.in() != 0)
@@ -245,10 +246,10 @@ TAO_IIOP_Profile::parse_string_i (const char *ior)
               this->endpoint_.port_ = ia.get_port_number ();
             }
         }
-      length_host = cp_pos - ior;
+      length_host = ACE_Utils::truncate_cast<CORBA::ULong> (cp_pos - ior);
     }
   else
-    length_host = okd - ior;
+    length_host = ACE_Utils::truncate_cast<CORBA::ULong> (okd - ior);
 
 #if defined (ACE_HAS_IPV6)
   if (ipv6_in_host)
