@@ -13,7 +13,7 @@ TAO_LF_Invocation_Event::~TAO_LF_Invocation_Event (void)
 }
 
 void
-TAO_LF_Invocation_Event::state_changed_i (int new_state)
+TAO_LF_Invocation_Event::state_changed_i (LFS_STATE new_state)
 {
   if (this->state_ == new_state)
     return;
@@ -61,28 +61,28 @@ TAO_LF_Invocation_Event::state_changed_i (int new_state)
 
 }
 
-int
-TAO_LF_Invocation_Event::successful (void) const
+bool
+TAO_LF_Invocation_Event::successful_i (void) const
 {
   return this->state_ == TAO_LF_Event::LFS_SUCCESS;
 }
 
-int
-TAO_LF_Invocation_Event::error_detected (void) const
+bool
+TAO_LF_Invocation_Event::error_detected_i (void) const
 {
   return (this->state_ == TAO_LF_Event::LFS_FAILURE
           || this->state_ == TAO_LF_Event::LFS_TIMEOUT
           || this->state_ == TAO_LF_Event::LFS_CONNECTION_CLOSED);
 }
 
-int
-TAO_LF_Invocation_Event::is_state_final (void)
+bool
+TAO_LF_Invocation_Event::is_state_final (void) const
 {
   if (this->state_ == TAO_LF_Event::LFS_TIMEOUT ||
       this->state_ == TAO_LF_Event::LFS_FAILURE)
-    return 1;
+    return true;
 
-  return 0;
+  return false;
 }
 
 TAO_END_VERSIONED_NAMESPACE_DECL
