@@ -35,8 +35,8 @@
 #include "tao/Adapter_Registry.h"
 #include "tao/ORB_Core_TSS_Resources.h"
 #include "tao/Service_Context_Handler_Registry.h"
-#include "ace/Array_Map.h"
 
+#include "ace/Array_Map.h"
 #include "ace/Thread_Manager.h"
 #include "ace/Lock_Adapter_T.h"
 #include "ace/TSS_T.h"
@@ -383,7 +383,7 @@ public:
   /// transports.
   ACE_Allocator *transport_message_buffer_allocator (void);
 
-  /// The Message Blocks used for input CDRs must have appropiate
+  /// The Message Blocks used for input CDRs must have appropriate
   /// locking strategies.
   ACE_Data_Block *create_input_cdr_data_block (size_t size);
 
@@ -899,7 +899,7 @@ public:
   ACE_Service_Gestalt* configuration () const;
 
   /// Get outgoing fragmentation strategy.
-  auto_ptr<TAO_GIOP_Fragmentation_Strategy>
+  TAO_GIOP_Fragmentation_Strategy*
   fragmentation_strategy (TAO_Transport * transport);
 
 #if (TAO_HAS_BUFFERING_CONSTRAINT_POLICY == 1)
