@@ -57,10 +57,10 @@ ACE_TIMEPROBE_EVENT_DESCRIPTIONS (TAO_ServantBase_Timeprobe_Description,
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-TAO_ServantBase::TAO_ServantBase (void)
+TAO_ServantBase::TAO_ServantBase (TAO_Operation_Table* optable)
   : TAO_Abstract_ServantBase ()
   , ref_count_ (1)
-  , optable_ (0)
+  , optable_ (optable)
 {
 }
 
@@ -74,7 +74,10 @@ TAO_ServantBase::TAO_ServantBase (const TAO_ServantBase &rhs)
 TAO_ServantBase &
 TAO_ServantBase::operator= (const TAO_ServantBase &rhs)
 {
-  this->optable_ = rhs.optable_;
+  if (this != &rhs)
+  {
+    this->optable_ = rhs.optable_;
+  }
   return *this;
 }
 
