@@ -1,5 +1,3 @@
-// $Id: Thread_Pool.cpp 96992 2013-04-11 18:07:48Z huangh $
-
 #include "tao/RTCORBA/Thread_Pool.h"
 
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
@@ -393,8 +391,8 @@ TAO_Thread_Lane::current_threads (void) const
                     this->lock_,
                     0);
 
-  return (this->static_threads_.thr_count () +
-         this->dynamic_threads_.thr_count ());
+  return static_cast<CORBA::ULong> (this->static_threads_.thr_count () +
+                                    this->dynamic_threads_.thr_count ());
 }
 
 
@@ -498,7 +496,7 @@ TAO_Thread_Pool::TAO_Thread_Pool (TAO_Thread_Pool_Manager &manager,
     allow_request_buffering_ (allow_request_buffering),
     max_buffered_requests_ (max_buffered_requests),
     max_request_buffer_size_ (max_request_buffer_size),
-    lifespan_ (lifespan),
+    // lifespan_ (lifespan),
     dynamic_thread_time_ (dynamic_thread_time),
     lanes_ (0),
     number_of_lanes_ (1),
@@ -539,7 +537,7 @@ TAO_Thread_Pool::TAO_Thread_Pool (TAO_Thread_Pool_Manager &manager,
     allow_request_buffering_ (allow_request_buffering),
     max_buffered_requests_ (max_buffered_requests),
     max_request_buffer_size_ (max_request_buffer_size),
-    lifespan_ (lifespan),
+    // lifespan_ (lifespan),
     dynamic_thread_time_ (dynamic_thread_time),
     lanes_ (0),
     number_of_lanes_ (lanes.length ()),
