@@ -23,6 +23,7 @@
 #include /**/ "tao/Versioned_Namespace.h"
 #include "tao/Basic_Types.h"
 
+#include "ace/Auto_Ptr.h"
 #include "ace/Service_Object.h"
 #include "ace/Unbounded_Set.h"
 #include "ace/SString.h"
@@ -235,7 +236,7 @@ public:
   virtual TAO_LF_Strategy *create_lf_strategy (void) = 0;
 
   /// Outgoing fragment creation strategy.
-  virtual auto_ptr<TAO_GIOP_Fragmentation_Strategy>
+  virtual TAO_GIOP_Fragmentation_Strategy*
     create_fragmentation_strategy (TAO_Transport * transport,
                                    CORBA::ULong max_message_size) const = 0;
 
