@@ -1,6 +1,4 @@
 // -*- C++ -*-
-// $Id: TAO_Internal.cpp 96992 2013-04-11 18:07:48Z huangh $
-
 #include "tao/TAO_Internal.h"
 #include "tao/TAO_Singleton.h"
 #include "tao/default_server.h"
@@ -626,7 +624,7 @@ namespace
             if (TAO_debug_level > 0)
               {
                 TAOLIB_ERROR ((LM_ERROR,
-                            ACE_TEXT ("TAO (%P|%t) ORB_Core: ")
+                            ACE_TEXT ("TAO (%P|%t) - ORB_Core: ")
                             ACE_TEXT ("Unable to initialize ")
                             ACE_TEXT ("Codeset Manager\n")));
               }
