@@ -2,7 +2,6 @@ eval '(exit $?0)' && eval 'exec perl -S $0 ${1+"$@"}'
     & eval 'exec perl -S $0 $argv:q'
     if 0;
 
-# $Id: run_test.pl 97679 2014-04-04 08:47:51Z mcorino $
 # -*- perl -*-
 
 use lib "$ENV{ACE_ROOT}/bin";
@@ -69,11 +68,13 @@ if ($server->GetFile ($logbase) == -1) {
     exit 1;
 }
 
-if ($status == 0) {
+#if ($status == 0) {
     if (open(FH, $server_logfile)) {
         my $error_achieved = 0;
         my $reregister = 0;
+        print STDERR "processing <$server_logfile>\n";
         while(<FH>) {
+            print STDERR $_;
             if (/TAO_Acceptor::handle_accept_error.+Too many files open/) {
                 ++$error_achieved;
             }
@@ -84,19 +85,19 @@ if ($status == 0) {
         close(FH);
 
         if (!$error_achieved) {
-            print "ERROR: The error situation was not achieved\n";
+            print STDERR "ERROR: The error situation was not achieved\n";
             ++$status;
         }
         if (!$reregister) {
-            print "ERROR: The acceptor was not reregistered\n";
+            print STDERR "ERROR: The acceptor was not reregistered\n";
             ++$status;
         }
     }
     else {
-        print "ERROR: Unable to read $server_logfile\n";
+        print STDERR "ERROR: Unable to read $server_logfile\n";
         ++$status;
     }
-}
+#}
 
 $server->DeleteFile($iorbase);
 $client->DeleteFile($iorbase);
