@@ -700,11 +700,11 @@ Param_Test_i::test_any (const CORBA::Any &a1,
   const char *str_in;
   Coffee_ptr coffee;
   Param_Test::Fixed_Array_forany array;
-  CORBA::ShortSeq *ub_short_sequence;
-  Param_Test::Bounded_Short_Seq *bd_short_sequence;
-  Param_Test::Fixed_Struct *fixed_structure;
-  Param_Test::Big_Union *big_union;
-  Param_Test::Small_Union *small_union;
+  const CORBA::ShortSeq *ub_short_sequence;
+  const Param_Test::Bounded_Short_Seq *bd_short_sequence;
+  const Param_Test::Fixed_Struct *fixed_structure;
+  const Param_Test::Big_Union *big_union;
+  const Param_Test::Small_Union *small_union;
 
   a2 = a1;
   a3 = new CORBA::Any (a1);
@@ -769,10 +769,11 @@ Param_Test_i::test_any (const CORBA::Any &a1,
             ACE_DEBUG ((LM_DEBUG, " %d", (*ub_short_sequence)[i]));
           ACE_DEBUG ((LM_DEBUG, "\n"));
         }
+      CORBA::ShortSeq newseq (*ub_short_sequence);
       for (size_t i = 0; i < ub_short_sequence->length (); i++)
-        (*ub_short_sequence)[i] = (CORBA::Short) (i * i);
-      a2   <<= *ub_short_sequence;
-      *ret <<= *ub_short_sequence;
+        newseq[i] = (CORBA::Short) (i * i);
+      a2   <<= newseq;
+      *ret <<= newseq;
     }
   else if (a1 >>= bd_short_sequence)
     {
@@ -783,10 +784,11 @@ Param_Test_i::test_any (const CORBA::Any &a1,
             ACE_DEBUG ((LM_DEBUG, " %d", (*bd_short_sequence)[i]));
           ACE_DEBUG ((LM_DEBUG, "\n"));
         }
+      Param_Test::Bounded_Short_Seq newseq (*bd_short_sequence);
       for (size_t i = 0; i < bd_short_sequence->length (); i++)
-        (*bd_short_sequence)[i] = (CORBA::Short) (i * i);
-      a2 <<= *bd_short_sequence;
-      *ret <<= *bd_short_sequence;
+        newseq[i] = (CORBA::Short) (i * i);
+      a2 <<= newseq;
+      *ret <<= newseq;
     }
   else if (a1 >>= fixed_structure)
     {
@@ -795,7 +797,7 @@ Param_Test_i::test_any (const CORBA::Any &a1,
     }
   else if (a1 >>= big_union)
     {
-      Param_Test::Big_Union *bu_in, *bu_inout, *bu_out, *bu_ret;
+      const Param_Test::Big_Union *bu_in, *bu_inout, *bu_out, *bu_ret;
       a1 >>= bu_in;
 
       // Insert copies....
@@ -821,7 +823,7 @@ Param_Test_i::test_any (const CORBA::Any &a1,
     }
   else if (a1 >>= small_union)
     {
-      Param_Test::Small_Union *bu_in, *bu_inout, *bu_out, *bu_ret;
+      const Param_Test::Small_Union *bu_in, *bu_inout, *bu_out, *bu_ret;
       a1 >>= bu_in;
 
       // Insert copies....
