@@ -1,8 +1,7 @@
 #include "Hello.h"
 
 Hello::Hello (CORBA::ORB_ptr orb)
-  : length_ (40000u)
-  , orb_ (CORBA::ORB::_duplicate (orb))
+  : orb_ (CORBA::ORB::_duplicate (orb))
 {
 }
 
@@ -14,14 +13,14 @@ Hello::get_string (const char * mystring)
 }
 
 Test::Octet_Seq *
-Hello::get_big_reply ()
+Hello::get_big_reply (CORBA::ULong size)
 {
   Test::Octet_Seq_var reply_mesg =
-    new Test::Octet_Seq (this->length_);
+    new Test::Octet_Seq (size);
 
-  reply_mesg->length (this->length_);
+  reply_mesg->length (size);
 
-  for (unsigned int i = 0u; i < this->length_; ++i)
+  for (CORBA::ULong i = 0u; i < size; ++i)
     {
       reply_mesg[i]= static_cast<CORBA::Octet> (i & 0xff);
     }
@@ -34,12 +33,13 @@ Hello::big_request (const ::Test::Octet_Seq & octet_in)
   if (octet_in.length () > 0)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT("Server side BLOB received\n")));
+                  ACE_TEXT("Server side BLOB received len = %d\n"),
+                  octet_in.length ()));
     }
   else
     {
       ACE_DEBUG ((LM_ERROR,
-                  ACE_TEXT("Error recieving BLOB on server\n")));
+                  ACE_TEXT("Error receiving BLOB on server\n")));
     }
 }
 
